==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebCancelableEventArgsDescription } from "./WebCancelableEventArgsDescription";
/**
 * @hidden
 */
var WebCancelableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableEventArgsDescriptionMetadata, _super);
    function WebCancelableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableEventArgsDescriptionMetadata.b = function (a) {
        if (WebCancelableEventArgsDescriptionMetadata.a == null) {
            WebCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableEventArgsDescriptionMetadata.c(WebCancelableEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebCancelableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCancelableEventArgsDescriptionMetadata.a);
        WebCancelableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebCancelableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CancelableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebCancelableEventArgsDetail");
    };
    WebCancelableEventArgsDescriptionMetadata.d = function (a) {
        WebCancelableEventArgsDescriptionMetadata.b(a);
        a.aa("WebCancelableEventArgs", function () { return new WebCancelableEventArgsDescription(); });
        a.z("WebCancelableEventArgs", WebCancelableEventArgsDescriptionMetadata.a);
    };
    WebCancelableEventArgsDescriptionMetadata.$t = markType(WebCancelableEventArgsDescriptionMetadata, 'WebCancelableEventArgsDescriptionMetadata');
    WebCancelableEventArgsDescriptionMetadata.a = null;
    return WebCancelableEventArgsDescriptionMetadata;
}(Base));
export { WebCancelableEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCancelableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebCancelableEventArgsDescription } from "./WebCancelableEventArgsDescription";
/**
 * @hidden
 */
var WebCancelableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableEventArgsDescriptionMetadata, _super);
    function WebCancelableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableEventArgsDescriptionMetadata.b = function (a) {
        if (WebCancelableEventArgsDescriptionMetadata.a == null) {
            WebCancelableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableEventArgsDescriptionMetadata.c(WebCancelableEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebCancelableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCancelableEventArgsDescriptionMetadata.a);
        WebCancelableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebCancelableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CancelableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebCancelableEventArgsDetail");
    };
    WebCancelableEventArgsDescriptionMetadata.d = function (a) {
        WebCancelableEventArgsDescriptionMetadata.b(a);
        a.ac("WebCancelableEventArgs", function () { return new WebCancelableEventArgsDescription(); });
        a.ab("WebCancelableEventArgs", WebCancelableEventArgsDescriptionMetadata.a);
    };
    WebCancelableEventArgsDescriptionMetadata.$t = markType(WebCancelableEventArgsDescriptionMetadata, 'WebCancelableEventArgsDescriptionMetadata');
    WebCancelableEventArgsDescriptionMetadata.a = null;
    return WebCancelableEventArgsDescriptionMetadata;
}(Base));
export { WebCancelableEventArgsDescriptionMetadata };
